import pytest

from adventocr import parse


@pytest.mark.parametrize('text', [
    [[1, 1, 1, 1, 0],
     [1, 0, 0, 0, 0],
     [1, 1, 1, 0, 0],
     [1, 0, 0, 0, 0],
     [1, 0, 0, 0, 0],
     [1, 1, 1, 1, 0]]
])
def test_letter(text):
    assert parse.letter(text) == 'E'


@pytest.mark.parametrize('rows', [
    [
        1, 1, 1, 1, 0, 1, 1, 1, 1, 0,
        1, 0, 0, 0, 0, 1, 0, 0, 0, 0,
        1, 1, 1, 0, 0, 1, 1, 1, 0, 0,
        1, 0, 0, 0, 0, 1, 0, 0, 0, 0,
        1, 0, 0, 0, 0, 1, 0, 0, 0, 0,
        1, 1, 1, 1, 0, 1, 0, 0, 0, 0],
    [
        1, 1, 1, 1, 0, 1, 1, 1, 1, 0, '\n',
        1, 0, 0, 0, 0, 1, 0, 0, 0, 0, '\n',
        1, 1, 1, 0, 0, 1, 1, 1, 0, 0, '\n',
        1, 0, 0, 0, 0, 1, 0, 0, 0, 0, '\n',
        1, 0, 0, 0, 0, 1, 0, 0, 0, 0, '\n',
        1, 1, 1, 1, 0, 1, 0, 0, 0, 0
    ],
    '111101111010000100001110011100100001000010000100001111010000',
    '1111011110\n1000010000\n1110011100\n1000010000\n1000010000\n1111010000'
])
def test_word_multiple_letters(rows):
    assert parse.word(rows) == 'EF'


@pytest.mark.parametrize('rows', [
    [
        1, 1, 1, 1, 0,
        1, 0, 0, 0, 0,
        1, 1, 1, 0, 0,
        1, 0, 0, 0, 0,
        1, 0, 0, 0, 0,
        1, 1, 1, 1, 0],
    [
        1, 1, 1, 1, 0, '\n',
        1, 0, 0, 0, 0, '\n',
        1, 1, 1, 0, 0, '\n',
        1, 0, 0, 0, 0, '\n',
        1, 0, 0, 0, 0, '\n',
        1, 1, 1, 1, 0,
    ],
    '111101000011100100001000011110',
    '11110\n10000\n11100\n10000\n10000\n11110'
])
def test_word_single_letter(rows):
    assert parse.word(rows) == 'E'
